==> kubernetes-model-0.1.5-sources.jar: annotations/io/fabric8/kubernetes/api/model/QuantityBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.HashMap;
import java.util.Map;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Visitable;

public class QuantityBuilder extends QuantityFluent<QuantityBuilder> implements VisitableBuilder<Quantity,QuantityBuilder>{

     QuantityFluent<?> fluent;
public QuantityBuilder(){
    this(new Quantity());
}
public QuantityBuilder( QuantityFluent<?> fluent ){
    this(fluent, new Quantity());
}
public QuantityBuilder( QuantityFluent<?> fluent , Quantity instance ){
    this.fluent = fluent; fluent.withAmount(instance.getAmount()); 
}
public QuantityBuilder( Quantity instance ){
    this.fluent = this; this.withAmount(instance.getAmount()); 
}

public EditableQuantity build(){
    EditableQuantity buildable = new EditableQuantity(fluent.getAmount());
validate(buildable);
return buildable;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.33-sources.jar: annotations/io/fabric8/kubernetes/api/model/QuantityBuilder.java <==
package io.fabric8.kubernetes.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import java.util.Map;
import java.util.HashMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Builder;

public class QuantityBuilder extends QuantityFluentImpl<QuantityBuilder> implements VisitableBuilder<Quantity,QuantityBuilder>{

     QuantityFluent<?> fluent;
public QuantityBuilder(){
    this(new Quantity());
}
public QuantityBuilder( QuantityFluent<?> fluent ){
    this(fluent, new Quantity());
}
public QuantityBuilder( QuantityFluent<?> fluent , Quantity instance ){
    this.fluent = fluent; fluent.withAmount(instance.getAmount()); 
}
public QuantityBuilder( Quantity instance ){
    this.fluent = this; this.withAmount(instance.getAmount()); 
}

public EditableQuantity build(){
    EditableQuantity buildable = new EditableQuantity(fluent.getAmount());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
QuantityBuilder that = (QuantityBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}
